**Example 1: 批量删除权限规则**

批量删除权限规则

Input: 

```
tccli chdfs DeleteAccessRules --cli-unfold-argument  \
    --AccessRuleIds 13001 13002
```

Output: 
```
{
    "Response": {
        "RequestId": "b629358c-ed40-4747-9060-3fcd34a8f32f"
    }
}
```

